@@ -1,13 +1,13 @@
 #
 # This file is part of Config-Model-Tester
 #
-# This software is Copyright (c) 2013-2019 by Dominique Dumont.
+# This software is Copyright (c) 2013-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Tester 4.004;
+package Config::Model::Tester 4.006;
 # ABSTRACT: Test framework for Config::Model
 
 use warnings;
@@ -26,13 +26,9 @@ use Test::Exception;
 use Test::File::Contents ;
 use Test::Differences;
 use Test::Memory::Cycle ;
-use Test::Log::Log4perl;
 
 use Config::Model::Tester::Setup qw/init_test setup_test_dir/;
 
-Test::Log::Log4perl->ignore_priority("info");
-
-
 # use eval so this module does not have a "hard" dependency on Config::Model
 # This way, Config::Model can build-depend on Config::Model::Tester without
 # creating a build dependency loop.
@@ -97,10 +93,13 @@ sub setup_test {
             my $data = $data_file->slurp() ;
             $destination->spew( $data );
             if (ref $map eq 'ARRAY') {
-                foreach my $link (@$map) {
-                    $link =~ s!~/!$home_for_test/! if $home_for_test;
-                    symlink $destination->absolute->stringify, $wr_dir->child($link)->stringify
-                        unless $destination eq $link;
+                my @tmp = @$map;
+                pop @tmp; # remove destination
+                foreach my $link_str (@tmp) {
+                    $link_str =~ s!~/!$home_for_test/! if $home_for_test;
+                    my $link = $wr_dir->child($link_str);
+                    $link->parent->mkpath( { mode => oct(755) }) ;
+                    symlink $destination->absolute->stringify, $link->stringify;
                 }
             }
             @file_list = list_test_files ($wr_dir);
@@ -234,7 +233,7 @@ sub apply_fix {
 }
 
 sub dump_tree {
-    my ($test_group, $root, $mode, $no_warnings, $t, $trace) = @_;
+    my ($test_group, $root, $mode, $no_warnings, $t, $test_logs, $trace) = @_;
 
     print "dumping tree ...\n" if $trace;
     my $dump  = '';
@@ -254,17 +253,21 @@ sub dump_tree {
         }
     }
 
-    if ( my $info = $t->{log4perl_dump_warnings} or $::_use_log4perl_to_warn) {
+    if ( $test_logs and (my $info = $t->{log4perl_dump_warnings} or $::_use_log4perl_to_warn)) {
         note("checking logged warning while dumping");
         my $tw = Test::Log::Log4perl->expect( @{$info // [] } );
         $risky->();
     }
-    elsif ( ($no_warnings or (exists $t->{dump_warnings}) and not defined $t->{dump_warnings}) ) {
+    elsif ( not $test_logs or $no_warnings ) {
         local $Config::Model::Value::nowarning = 1;
-        note("dump_warnings parameter is DEPRECATED") if exists $t->{dump_warnings};
         &$risky;
         ok( 1, "Ran dump_tree (no warning check)" );
     }
+    elsif ( exists $t->{dump_warnings} and not defined $t->{dump_warnings} ) {
+        local $Config::Model::Value::nowarning = 1;
+        &$risky;
+        ok( 1, "Ran dump_tree with DEPRECATED dump_warnings parameter (no warning check)" );
+    }
     else {
         note("dump_warnings parameter is DEPRECATED") if $t->{dump_warnings};
         warnings_like { &$risky; } $t->{dump_warnings}, "Ran dump_tree";
@@ -563,7 +566,7 @@ sub load_test_suite_data {
 }
 
 sub run_model_test {
-    my ($test_group, $test_group_conf, $do, $model, $trace, $wr_root) = @_ ;
+    my ($test_group, $test_group_conf, $do, $model, $trace, $wr_root, $test_logs) = @_ ;
 
     my $test_suite_data = load_test_suite_data($model,$test_group, $test_group_conf);
     my $appli_info = $test_suite_data->{appli_info};
@@ -615,20 +618,20 @@ sub run_model_test {
 
         my $root = $inst->config_root;
 
-        check_load_warnings ($root,$t);
+        check_load_warnings ($root,$t) if $test_logs;
 
         run_update($inst,$wr_dir,$t) if $t->{update};
 
         load_instructions ($root,$t->{load},$trace) if $t->{load} ;
 
-        dump_tree ('before fix '.$test_group , $root, 'full', $t->{no_warnings}, $t->{check_before_fix}, $trace)
+        dump_tree ('before fix '.$test_group , $root, 'full', $t->{no_warnings}, $t->{check_before_fix}, $test_logs, $trace)
             if $t->{check_before_fix};
 
         apply_fix($inst) if  $t->{apply_fix};
 
-        dump_tree ($test_group, $root, 'full', $t->{no_warnings}, $t->{full_dump}, $trace) ;
+        dump_tree ($test_group, $root, 'full', $t->{no_warnings}, $t->{full_dump}, $test_logs, $trace) ;
 
-        my $dump = dump_tree ($test_group, $root, 'custom', $t->{no_warnings}, {}, $trace) ;
+        my $dump = dump_tree ($test_group, $root, 'custom', $t->{no_warnings}, {}, $test_logs, $trace) ;
 
         check_data("first", $root, $t->{check}, $t->{no_warnings}) if $t->{check};
 
@@ -649,7 +652,7 @@ sub run_model_test {
 
         load_instructions ($i2_root,$t->{load2},$trace) if $t->{load2} ;
 
-        my $p2_dump = dump_tree("second $test_group", $i2_root, 'custom', $t->{no_warnings},{}, $trace) ;
+        my $p2_dump = dump_tree("second $test_group", $i2_root, 'custom', $t->{no_warnings},{}, $test_logs, $trace) ;
 
         unified_diff;
         eq_or_diff(
@@ -691,6 +694,7 @@ sub create_model_object {
 sub run_tests {
     my ( $test_only_app, $do, $trace, $wr_root );
     my $model;
+    my $test_logs;
     if (@_) {
         my $arg;
         note ("Calling run_tests with argument is deprecated");
@@ -718,7 +722,9 @@ sub run_tests {
         $wr_root = path('wr_root');
     }
     else {
-        ($model, $trace) = init_test();
+        my $opts;
+        ($model, $trace, $opts) = init_test();
+        $test_logs = $opts->{log} ? 0 : 1;
         ( $test_only_app, $do)  = @ARGV;
         # pseudo root where config files are written by config-model
         $wr_root = setup_test_dir();
@@ -731,7 +737,7 @@ sub run_tests {
         next if ( $test_only_app and $test_only_app ne $test_group ) ;
         $model = create_model_object();
         return unless $model;
-        run_model_test($test_group, $test_group_conf, $do, $model, $trace, $wr_root) ;
+        run_model_test($test_group, $test_group_conf, $do, $model, $trace, $wr_root, $test_logs) ;
     }
 
     memory_cycle_ok($model,"test memory cycle") ;
@@ -753,7 +759,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 4.004
+version 4.006
 
 =head1 SYNOPSIS
 
@@ -1101,10 +1107,13 @@ The Log classes are specified in C<cme/Logging>.
 
 Log levels below "warn" are ignored.
 
+Note that log tests are disabled when C<--log> option is used, hence
+all warnings triggered by the tests are shown.
+
 L<Config::Model> is currently transitioning from traditional "warn" to
 warn logs. To avoid breaking all tests based on this module, the
 warnings are emitted through L<Log::Log4Perl> only when
-c<$::_use_log4perl_to_warn> is set. This hack will be removed once all
+C<$::_use_log4perl_to_warn> is set. This hack will be removed once all
 warnings checks in tests are ported to log4perl checks.
 
 =item *
@@ -1505,13 +1514,13 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013-2019 by Dominique Dumont.
+This software is Copyright (c) 2013-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
   The GNU Lesser General Public License, Version 2.1, February 1999
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -1524,30 +1533,6 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Config-Model-Tester>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Config-Model-Tester>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Config-Model-Tester>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
